<?php

/**
  ReduxFramework Sample Config File
  For full documentation, please visit: https://docs.reduxframework.com
 * */

if (!class_exists('admin_folder_Redux_Framework_config')) {

	class admin_folder_Redux_Framework_config {

		public $aqura_args        = array();
		public $sections    = array();
		public $theme;
		public $ReduxFramework;

		public function __construct() {

			if (!class_exists('ReduxFramework')) {
				return;
			}

			// This is needed. Bah WordPress bugs.  ;)
			if ( true == Redux_Helpers::isTheme( __FILE__ ) ) {
				$this->initSettings();
			} else {
				add_action('plugins_loaded', array($this, 'initSettings'), 10);
			}

		}

		public function initSettings() {

			// Just for demo purposes. Not needed per say.
			$this->theme = wp_get_theme();

			// Set the default arguments
			$this->setArguments();

			// Set a few help tabs so you can see how it's done
			$this->setHelpTabs();

			// Create the sections and fields
			$this->setSections();

			if (!isset($this->args['opt_name'])) { // No errors please
				return;
			}

			// If Redux is running as a plugin, this will remove the demo notice and links
			add_action( 'redux/loaded', array( $this, 'remove_demo' ) );

			$this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
		}

		/**

		  Custom function for filtering the sections array. Good for child themes to override or add to the sections.
		  Simply include this function in the child themes functions.php file.

		  NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
		  so you must use get_template_directory_uri() if you want to use any of the built in icons

		 * */
		function dynamic_section($sections) {
			//$sections = array();
			$sections[] = array(
				'title' => esc_html__('Section via hook', 'aqura'),
				'desc' => esc_html__('<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'aqura'),
				'icon' => 'el-icon-paper-clip',
				// Leave this as a blank section, no options just some intro text set above.
				'fields' => array()
			);

			return $sections;
		}

		/**

		  Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.

		 * */
		function change_arguments($aqura_args) {
			//$aqura_args['dev_mode'] = true;

			return $aqura_args;
		}

		/**

		  Filter hook for filtering the default value of any given field. Very useful in development mode.

		 * */
		function change_defaults($defaults) {
			$defaults['str_replace'] = 'Testing filter hook!';

			return $defaults;
		}

		// Remove the demo link and the notice of integrated demo from the redux-framework plugin
		function remove_demo() {

			// Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
			if (class_exists('ReduxFrameworkPlugin')) {
				remove_filter('plugin_row_meta', array(ReduxFrameworkPlugin::instance(), 'plugin_metalinks'), null, 2);

				// Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
				remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
			}
		}

		public function setSections() {

			/**
			  Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
			 * */
			// Background Patterns Reader
			$sample_patterns_path   = ReduxFramework::$_dir . '../sample/patterns/';
			$sample_patterns_url    = ReduxFramework::$_url . '../sample/patterns/';
			$sample_patterns        = array();

			if (is_dir($sample_patterns_path)) :

				if ($sample_patterns_dir = opendir($sample_patterns_path)) :
					$sample_patterns = array();

					while (( $sample_patterns_file = readdir($sample_patterns_dir) ) !== false) {

						if (stristr($sample_patterns_file, '.png') !== false || stristr($sample_patterns_file, '.jpg') !== false) {
							$name = explode('.', $sample_patterns_file);
							$name = str_replace('.' . end($name), '', $sample_patterns_file);
							$sample_patterns[]  = array('alt' => $name, 'img' => $sample_patterns_url . $sample_patterns_file);
						}
					}
				endif;
			endif;

			ob_start();

			$ct             = wp_get_theme();
			$this->theme    = $ct;
			$item_name      = $this->theme->get('Name');
			$tags           = $this->theme->Tags;
			$screenshot     = $this->theme->get_screenshot();
			$class          = $screenshot ? 'has-screenshot' : '';

			$customize_title = sprintf(__('Customize &#8220;%s&#8221;', 'aqura'), $this->theme->display('Name'));
			
			?>
			<div id="current-theme" class="<?php echo esc_attr($class); ?>">
			<?php if ($screenshot) : ?>
				<?php if (current_user_can('edit_theme_options')) : ?>
						<a href="<?php echo wp_customize_url(); ?>" class="load-customize hide-if-no-customize" title="<?php echo esc_attr($customize_title); ?>">
							<img src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview','aqura'); ?>" />
						</a>
				<?php endif; ?>
					<img class="hide-if-customize" src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview','aqura'); ?>" />
				<?php endif; ?>

				<h4><?php echo esc_html($this->theme->display('Name')); ?></h4>

				<div>
					<ul class="theme-info">
						<li><?php printf(__('By %s', 'aqura'), $this->theme->display('Author')); ?></li>
						<li><?php printf(__('Version %s', 'aqura'), $this->theme->display('Version')); ?></li>
						<li><?php echo '<strong>' . esc_html__('Tags', 'aqura') . ':</strong> '; ?><?php printf($this->theme->display('Tags')); ?></li>
					</ul>
					<p class="theme-description"><?php echo esc_html($this->theme->display('Description')); ?></p>
			<?php
			if ($this->theme->parent()) {
				printf(' <p class="howto">' . esc_html__('This <a href="%1$s">child theme</a> requires its parent theme, %2$s.','aqura') . '</p>', esc_html__('http://codex.wordpress.org/Child_Themes', 'aqura'), $this->theme->parent()->display('Name'));
			}
			?>

				</div>
			</div>

			<?php
			$item_info = ob_get_contents();

			ob_end_clean();

			$sampleHTML = '';
			if (file_exists(get_template_directory() . '/info-html.html')) {
				/** @global WP_Filesystem_Direct $wp_filesystem  */
				global $wp_filesystem;
				if (empty($wp_filesystem)) {
					require_once(ABSPATH . '/wp-admin/includes/file.php');
					WP_Filesystem();
				}
				$sampleHTML = $wp_filesystem->get_contents(get_template_directory() . '/info-html.html');
			}

			// ACTUAL DECLARATION OF SECTIONS
			// Here comes the sections.
			$this->sections[] = array(
				'icon'      => 'el-icon-cogs',
				'title'     => esc_html__('General Settings', 'aqura'),
				'fields'    => array(
					array(
						'id'        => 'favico',
						'type'      => 'media',
						'url'       => true,
						'title'     => esc_html__('Favicon', 'aqura'),
						'compiler'  => 'true',
						'desc'      => esc_html__('An .ico file named "favicon" (16x16 px) that will show in the browsers tab and feed.', 'aqura'),
						'subtitle'  => esc_html__('Upload here the favicon image.', 'aqura'),
						'default'   => array('url' => AQURA_THEMEROOT . '/assets/img/favicon.ico'),
					),
					array(
						'id'        => 'logo',
						'type'      => 'media',
						'url'       => true,
						'title'     => esc_html__('Logo Light', 'aqura'),
						'compiler'  => 'true',
						'subtitle'  => esc_html__('Upload here the light logo image.', 'aqura'),
						'default'   => array('url' => AQURA_THEMEROOT . '/assets/img/logo/whiteLogo.png'),
					),
					array(
						'id'        => 'logo_dark',
						'type'      => 'media',
						'url'       => true,
						'title'     => esc_html__('Logo Dark', 'aqura'),
						'compiler'  => 'true',
						'subtitle'  => esc_html__('Upload here the dark logo image.', 'aqura'),
						'default'   => array('url' => AQURA_THEMEROOT . '/assets/img/logo/logo.png'),
					),
					array(
						'id'        => 'csscode',
						'type'      => 'ace_editor',
						'title'     => esc_html__('CSS Code', 'aqura'),
						'subtitle'  => esc_html__('Paste your CSS code here.', 'aqura'),
						'mode'      => 'css',
						'theme'     => 'monokai',
						'desc'      => 'Possible modes can be found at <a href="http://ace.c9.io" target="_blank">http://ace.c9.io/</a>.',
						'default'   => ""
					)
				));

			// $this->sections[] = array(
			// 	'icon'      => 'el-icon-lines',
			// 	'title'     => esc_html__('Header Options', 'aqura'),
			// 	'fields'    => array(
			// 		array(
			// 			'id'       => 'header-select',
			// 			'type'     => 'select',
			// 			'title'    => esc_html__('Select Header Style', 'aqura'),
			// 			'options'  => array(
			// 				'1' => esc_html__('With Trigger Button', 'aqura'),
			// 				'2' => esc_html__('Inline In Header', 'aqura')
			// 			),
			// 			'default'  => '1',
			// 		)
			// 	));

			$this->sections[] = array(
				'title'      => esc_html__( 'SoundCloud', 'aqura' ),
				'desc'       => esc_html__( 'Setup the SoundCloud integration.', 'aqura' ),
				'id'         => 'players-soundcloud',
				'fields'     => array(
					array(
						'id'       => 'soundcloud_client_id',
						'type'     => 'text',
						'title'    => esc_html__( 'Client ID', 'aqura' ),
						'description' => __('You can see how to get your Client ID <a target="_blank" href="https://www.youtube.com/watch?v=DdDqV0NrSOg">here</a>.','aqura')
					)
				));

			$this->sections[] = array(
				'icon'      => 'el-icon-list-alt',
				'title'     => esc_html__('Footer Options', 'aqura'),
				//'desc'      => esc_html__('<p class="description">Here you can customize most of the display of Clubix.</p>', 'aqura'),
				'fields'    => array(
					array(
						'id'        => 'footer-color',
						'type'      => 'color',
						'title'     => esc_html__('Footer Background Color', 'aqura'),
						//'subtitle'  => esc_html__('HTML Allowed (wp_kses)', 'aqura'),
						//'desc'      => esc_html__('This is the description field, again good for additional info.', 'aqura'),
						'default'   => '#eeeeee'
					),
					array(
						'id'        => 'copyright',
						'type'      => 'textarea',
						'title'     => esc_html__('Footer Copyright', 'aqura'),
						//'subtitle'  => esc_html__('HTML Allowed (wp_kses)', 'aqura'),
						//'desc'      => esc_html__('This is the description field, again good for additional info.', 'aqura'),
						'validate'  => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
						'default'   => '© AQURA 2016'
					),
				));

			$this->sections[] = array(
				'icon'      => 'el-icon-address-book',
				'title'     => esc_html__('Contact & Social Options', 'aqura'),
				//'desc'      => esc_html__('<p class="description">Here you can customize most of the display of Clubix.</p>', 'aqura'),
				'fields'    => array(
					array(
						'id'        => 'contact-email',
						'type'      => 'text',
						'title'     => esc_html__('Contact Email', 'aqura'),
						'subtitle'  => esc_html__('The e-mail address where it will send the messages.', 'aqura'),
						//'desc'      => esc_html__('This is the description field, again good for additional info.', 'aqura'),
						'validate'  => 'email',
						'msg'       => 'The email address is not right.',
						'default'   => 'test@test.com',
					),
					array(
						'id'        => 'contact-phone',
						'type'      => 'multi_text',
						'title'     => esc_html__('Contact Phone', 'aqura'),
						'default'   => array('+4070 547 235 125')
					),
					array(
						'id'        => 'contact-fax',
						'type'      => 'multi_text',
						'title'     => esc_html__('Contact Fax', 'aqura'),
						'default'   => array('+4070 547 235 125')
					),
					array(
						'id'        => 'contact-address',
						'type'      => 'text',
						'title'     => esc_html__('Contact Address', 'aqura'),
						'subtitle'  => esc_html__('This address will be used for the google map on the contact page.', 'aqura'),
						//'desc'      => esc_html__('This is the description field, again good for additional info.', 'aqura'),
						//'validate'  => 'email',
						//'msg'       => 'The email address is not right.',
						'default'   => 'New York, USA',
					),
					array(
						'id'        => 'contact-title',
						'type'      => 'text',
						'title'     => esc_html__('Map Title', 'aqura'),
						'subtitle'  => esc_html__('This will appear when you click on the pointer.', 'aqura'),
						'default'   => 'Contact US',
					),
					array(
						'id'        => 'contact-description',
						'type'      => 'textarea',
						'title'     => esc_html__('Map Description', 'aqura'),
						'subtitle'  => esc_html__('This will appear when you click on the pointer.', 'aqura'),
						'default'   => 'Lorem ipsum dolor sit amet,incididunt ut labore et dolore psum dolor magna aliqua.',
					),
					array(
						'id'        => 'map-image',
						'type'      => 'media',
						'url'       => true,
						'title'     => esc_html__('Pointer Image', 'aqura'),
						'compiler'  => 'true',
						'default'   => array('url' => AQURA_THEMEROOT . '/assets/img/contact/marker.png'),
					),
					array(
						'id'        => 'social',
						'type'      => 'multi_text',
						'title'     => esc_html__('Social Icons', 'aqura'),
						//'validate'  => 'color',
						'subtitle'  => esc_html__('Add a icon shortcode usign a class from Font Awesome.', 'aqura'),
						//'desc'      => esc_html__('This is the description field, again good for additional info.', 'aqura')
						'default'   => array('[aqura_isocial icon="fa-facebook" href="#" /]','[aqura_isocial icon="fa-tumblr" href="#" /]', '[aqura_isocial icon="fa-twitter" href="#" /]')
					),
				));

			$this->sections[] = array(
				'icon'      => 'el-icon-map-marker',
				'title'     => esc_html__('Map Styling Options', 'aqura'),
				'fields'    => array(
					array(
						'id'        => 'geometry',
						'title'     => esc_html__('Geometry', 'aqura'),
						'type'      => 'color',
						'default'	=> '#f7f7f7'
					),
					array(
						'id'        => 'labels_text_stroke',
						'title'     => esc_html__('Labels Text Stroke', 'aqura'),
						'type'      => 'color',
						'default'	=> '#fff'
					),
					array(
						'id'        => 'labels_text_fill',
						'title'     => esc_html__('Labels Text Fill', 'aqura'),
						'type'      => 'color',
						'default'	=> '#82474e'
					),
					array(
						'id'        => 'geometry_poi_park',
						'title'     => esc_html__('Park', 'aqura'),
						'type'      => 'color',
						'default'	=> '#efefef'
					),
					array(
						'id'        => 'geometry_road',
						'title'     => esc_html__('Road', 'aqura'),
						'type'      => 'color',
						'default'	=> '#eabcc1'
					),
					array(
						'id'        => 'geometry_road_stroke',
						'title'     => esc_html__('Road Stroke', 'aqura'),
						'type'      => 'color',
						'default'	=> '#eabcc1'
					),
					array(
						'id'        => 'geometry_road_highway',
						'title'     => esc_html__('Road Highway', 'aqura'),
						'type'      => 'color',
						'default'	=> '#d89395'
					),
					array(
						'id'        => 'geometry_road_highway_stroke',
						'title'     => esc_html__('Road Highway Stroke', 'aqura'),
						'type'      => 'color',
						'default'	=> '#d37e89'
					),
					array(
						'id'        => 'geometry_transit',
						'title'     => esc_html__('Transit', 'aqura'),
						'type'      => 'color',
						'default'	=> '#e7e7e7'
					),
					array(
						'id'        => 'geometry_water',
						'title'     => esc_html__('Water', 'aqura'),
						'type'      => 'color',
						'default'	=> '#e9e9e9'
					),
					array(
						'id'        => 'geometry_water_stroke',
						'title'     => esc_html__('Water Stroke', 'aqura'),
						'type'      => 'color',
						'default'	=> '#f1f1f1'
					),
					array(
						'id'        => 'water_text',
						'title'     => esc_html__('Water Text', 'aqura'),
						'type'      => 'color',
						'default'	=> '#c3c3c3'
					),
					array(
						'id'        => 'administrative_locality_text',
						'title'     => esc_html__('Administrative Locality Text', 'aqura'),
						'type'      => 'color',
						'default'	=> '#9b9a9a'
					),
					array(
						'id'        => 'poi_text',
						'title'     => esc_html__('Poi Text', 'aqura'),
						'type'      => 'color',
						'default'	=> '#9b9a9a'
					),
					array(
						'id'        => 'poi_park_text',
						'title'     => esc_html__('Park Text', 'aqura'),
						'type'      => 'color',
						'default'	=> '#82474e'
					),
					array(
						'id'        => 'road_text',
						'title'     => esc_html__('Road Text', 'aqura'),
						'type'      => 'color',
						'default'	=> '#6c323a'
					),
					array(
						'id'        => 'roa_highway_text',
						'title'     => esc_html__('Road Highway Text', 'aqura'),
						'type'      => 'color',
						'default'	=> '#acacac'
					),
					array(
						'id'        => 'transit_station_text',
						'title'     => esc_html__('Transit Station Text', 'aqura'),
						'type'      => 'color',
						'default'	=> '#a7a7a7'
					),
				));

			$this->sections[] = array(
				'icon'      => 'el-icon-instagram',
				'title'     => esc_html__('Instragram', 'aqura'),
				'fields'    => array(
					array(
						'id'        => 'instagram-user-id',
						'type'      => 'text',
						'title'     => esc_html__('Instragram User ID', 'aqura'),
						'subtitle'  => esc_html__('You can find your ID here http://jelled.com/instagram/lookup-user-id .', 'aqura')
					),
					array(
						'id'        => 'instagram-user-token',
						'type'      => 'text',
						'title'     => esc_html__('Instragram User Token', 'aqura'),
						'subtitle'  => esc_html__('You can find your Token here http://instagram.pixelunion.net/ .', 'aqura')
					)
				));

			 $this->sections[] = array(
				'icon'      => 'el-icon-music',
				'title'     => esc_html__('Main Playlst', 'aqura'),
				'fields'    => array(
					array(
						'id'        => 'main-playlist-album-id',
						'type'      => 'text',
						'title'     => esc_html__('ID of an album to set the main playlist', 'aqura')
					)
				));

			$this->sections[] = array(
				'type' => 'divide',
			);


			$theme_info  = '<div class="redux-framework-section-desc">';
			$theme_info .= '<p class="redux-framework-theme-data description theme-uri">' . esc_html__('<strong>Theme URL:</strong> ', 'aqura') . '<a href="' . $this->theme->get('ThemeURI') . '" target="_blank">' . $this->theme->get('ThemeURI') . '</a></p>';
			$theme_info .= '<p class="redux-framework-theme-data description theme-author">' . esc_html__('<strong>Author:</strong> ', 'aqura') . $this->theme->get('Author') . '</p>';
			$theme_info .= '<p class="redux-framework-theme-data description theme-version">' . esc_html__('<strong>Version:</strong> ', 'aqura') . $this->theme->get('Version') . '</p>';
			$theme_info .= '<p class="redux-framework-theme-data description theme-description">' . $this->theme->get('Description') . '</p>';
			$tabs = $this->theme->get('Tags');
			if (!empty($tabs)) {
				$theme_info .= '<p class="redux-framework-theme-data description theme-tags">' . esc_html__('<strong>Tags:</strong> ', 'aqura') . implode(', ', $tabs) . '</p>';
			}
			$theme_info .= '</div>';

			$this->sections[] = array(
				'title'     => esc_html__('Import / Export', 'aqura'),
				'desc'      => esc_html__('Import and Export your Redux Framework settings from file, text or URL.', 'aqura'),
				'icon'      => 'el-icon-refresh',
				'fields'    => array(
					array(
						'id'            => 'opt-import-export',
						'type'          => 'import_export',
						'title'         => 'Import Export',
						'subtitle'      => 'Save and restore your Redux options',
						'full_width'    => false,
					),
				),
			);                     
					
			$this->sections[] = array(
				'type' => 'divide',
			);

			$this->sections[] = array(
				'icon'      => 'el-icon-info-sign',
				'title'     => esc_html__('Theme Information', 'aqura'),
				'desc'      => esc_html__('<p class="description">This is the Description. Again HTML is allowed</p>', 'aqura'),
				'fields'    => array(
					array(
						'id'        => 'opt-raw-info',
						'type'      => 'raw',
						'content'   => $item_info,
					)
				),
			);

		}

		public function setHelpTabs() {

			// Custom page help tabs, displayed using the help API. Tabs are shown in order of definition.
			$this->args['help_tabs'][] = array(
				'id'        => 'redux-help-tab-1',
				'title'     => esc_html__('Theme Information 1', 'aqura'),
				'content'   => esc_html__('<p>This is the tab content, HTML is allowed.</p>', 'aqura')
			);

			$this->args['help_tabs'][] = array(
				'id'        => 'redux-help-tab-2',
				'title'     => esc_html__('Theme Information 2', 'aqura'),
				'content'   => esc_html__('<p>This is the tab content, HTML is allowed.</p>', 'aqura')
			);

			// Set the help sidebar
			$this->args['help_sidebar'] = esc_html__('<p>This is the sidebar content, HTML is allowed.</p>', 'aqura');
		}

		/**

		  All the possible arguments for Redux.
		  For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments

		 * */
		public function setArguments() {

			$theme = wp_get_theme(); // For use with some settings. Not necessary.

			$this->args = array(
				'opt_name' => 'aqura_data',
				'page_slug' => 'aqura_options',
				'page_title' => 'Aqura Options',
				'update_notice' => '1',
				'admin_bar' => '1',
				'dev_mode'  => false,
				'menu_type' => 'menu',
				'menu_title' => 'Aqura Options',
				'allow_sub_menu' => '1',
				'page_parent_post_type' => 'your_post_type',
				'customizer' => '1',
				'hints' => 
				array(
				  'icon' => 'el-icon-question-sign',
				  'icon_position' => 'right',
				  'icon_size' => 'normal',
				  'tip_style' => 
				  array(
					'color' => 'light',
				  ),
				  'tip_position' => 
				  array(
					'my' => 'top left',
					'at' => 'bottom right',
				  ),
				  'tip_effect' => 
				  array(
					'show' => 
					array(
					  'duration' => '500',
					  'event' => 'mouseover',
					),
					'hide' => 
					array(
					  'duration' => '500',
					  'event' => 'mouseleave unfocus',
					),
				  ),
				),
				'output' => '1',
				'output_tag' => '1',
				'compiler' => '1',
				'page_icon' => 'icon-themes',
				'page_permissions' => 'manage_options',
				'save_defaults' => '1',
				'show_import_export' => '1',
				'transient_time' => '3600',
				'network_sites' => '1',
			  );

			// SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
			$this->args['share_icons'][] = array(
				'url'   => 'https://github.com/ReduxFramework/ReduxFramework',
				'title' => 'Visit us on GitHub',
				'icon'  => 'el-icon-github'
				//'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
			);
			$this->args['share_icons'][] = array(
				'url'   => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
				'title' => 'Like us on Facebook',
				'icon'  => 'el-icon-facebook'
			);
			$this->args['share_icons'][] = array(
				'url'   => 'http://twitter.com/reduxframework',
				'title' => 'Follow us on Twitter',
				'icon'  => 'el-icon-twitter'
			);
			$this->args['share_icons'][] = array(
				'url'   => 'http://www.linkedin.com/company/redux-framework',
				'title' => 'Find us on LinkedIn',
				'icon'  => 'el-icon-linkedin'
			);

		}

	}
	
	global $reduxConfig;
	$reduxConfig = new admin_folder_Redux_Framework_config();
}

/**
  Custom function for the callback referenced above
 */
if (!function_exists('admin_folder_my_custom_field')):
	function admin_folder_my_custom_field($field, $value) {
		print_r($field);
		echo '<br/>';
		print_r($value);
	}
endif;

/**
  Custom function for the callback validation referenced above
 * */
if (!function_exists('admin_folder_validate_callback_function')):
	function admin_folder_validate_callback_function($field, $value, $existing_value) {
		$error = false;
		$value = 'just testing';

		$return['value'] = $value;
		if ($error == true) {
			$return['error'] = $field;
		}
		return $return;
	}
endif;
