<?php
/**
 * The template for displaying comments.
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Aqura
 */

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}

global $user_identity;
$aqura_post_sidebar_hide = rwmb_meta( 'post_sidebar_hide' );
$aqura_commenter = wp_get_current_commenter();
$aqura_req = get_option( 'require_name_email' );
$aqura_aria_req = ( $aqura_req ? " aria-required='true'" : '' );

$aqura_fields =  array(
	'author' => '<input id="author" name="author" type="text" value="' . esc_attr($aqura_commenter['comment_author']) . '" ' . $aqura_aria_req . ' placeholder="' . esc_html__('Name... ', 'aqura') . '" />',

	'email' => '<input id="email" name="email" type="text" value="' . esc_attr($aqura_commenter['comment_author_email']) . '" ' . $aqura_aria_req . ' placeholder="' . esc_html__('Email... ', 'aqura') . '"/>',

	'website' => '<input id="website" name="website" type="text" value="' . esc_attr($aqura_commenter['comment_author_email']) . '" ' . $aqura_aria_req . ' placeholder="' . esc_html__('Website... ', 'aqura') . '"/>',

	'comment_field' => '<textarea id="comment" name="comment" cols="45" rows="8" aria-required="true" ' .
							'placeholder="' . esc_html__('Your comment ', 'aqura') . '"/>' .
						'</textarea>',
);

$aqura_args = array(
	'id_form'					 => 'commentform',
	'id_submit'				 => 'submit',
	'class_submit'			=> 'submit',
	'name_submit'			 => 'submit',
	'title_reply'			 => esc_html__( 'Leave a comment' , 'aqura' ),
	'title_reply_to'		=> esc_html__( 'Leave a comment to %s' , 'aqura' ),
	'cancel_reply_link' => esc_html__( 'Cancel Reply', 'aqura' ),
	'label_submit'			=> esc_html__( 'Post Comment' , 'aqura' ),
	'format'						=> 'xhtml',
	'comment_field' =>	'',
	'comment_notes_before' => '',
	'fields' => apply_filters( 'comment_form_default_fields', $aqura_fields ),
	'logged_in_as' => '<p class="logged-in-as">' . sprintf( esc_html__('Logged in as ', 'aqura') . '<a href="%1$s">%2$s</a>. <a href="%3$s" title="' . esc_html__('Log out of this account ', 'aqura') . '">' . esc_html__('Log out?', 'aqura') . '</a>', admin_url( 'profile.php' ), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink() ) ) ) . '</p>' . $aqura_fields['comment_field']
);

?>

<div class="comment-container">
	<?php
		// You can start editing here -- including this comment!
		if ( have_comments() ) : ?>
		<h1 class="title-comments">
			<?php
				comments_number(__('No Comments', 'aqura'), '1 ' . esc_html__(' Comment', 'aqura'), '% ' . esc_html__('Comments', 'aqura'));
			?>
		</h1>
		<!-- ============== COMMENTS ============= -->
		<ul class="comments pingback">
			<?php wp_list_comments( 'type=pingback&callback=aqura_comment_ping&short_ping=true' ); ?>
		</ul>
		<ul class="comments">
			<?php wp_list_comments( 'type=comment&callback=aqura_comment' ); ?>
		</ul>

	<?php else: ?>
				
		<p>
			<?php esc_html_e('No Comments Here. Be The First Who Comment!','aqura') ?>
		</p>

	<?php endif;


	// If comments are closed and there are comments, let's leave a little note, shall we?
	if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) : ?>

		<p class="no-comments"><?php esc_html_e('Comments are closed.', 'aqura'); ?></p>

	<?php endif; ?>

</div><!-- Comments -->
