<?php
/**
 * Aqura functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Aqura
 */

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }

if ( !defined( 'AQURA_THEMEROOT' ) ) {
	define('AQURA_THEMEROOT', get_template_directory_uri());
}

if ( !defined( 'AQURA_THEMEDIR' ) ) {
	define('AQURA_THEMEDIR', get_template_directory());
}

if ( !defined( 'AQURA_IMAGES' ) ) {
	define('AQURA_IMAGES', AQURA_THEMEROOT . '/assets/img');
}

if ( ! function_exists( 'aqura_main_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function aqura_main_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Aqura, use a find and replace
	 * to change 'aqura' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'aqura', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// Add theme support for WooCommerce plugin
	add_theme_support( 'woocommerce' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'aqura' ),
		// 'inline-primary-1' => esc_html__( 'Inline Style Primary 1', 'aqura' ),
		// 'inline-primary-2' => esc_html__( 'Inline Style Primary 2', 'aqura' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'aqura_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'aqura_main_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function aqura_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'aqura_content_width', 640 );
}
add_action( 'after_setup_theme', 'aqura_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function aqura_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'aqura' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'aqura' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'aqura_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function aqura_main_scripts() {
	wp_enqueue_script('bootstrap.min', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('plugins', get_template_directory_uri() . '/assets/js/plugins.js', array('jquery'), '1.0', true);
	wp_enqueue_script('map', get_template_directory_uri() . '/assets/js/map.js', array('jquery'), '1.0', true);
	wp_enqueue_script('aqura_main_js', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), '1.0', true);
	wp_enqueue_script('jquery.jplayer', get_template_directory_uri() . '/assets/jplayer/jplayer/jquery.jplayer.js', array('jquery'), '1.0', true);
	wp_enqueue_script('jPlayer', get_template_directory_uri() . '/assets/js/compressedJplayer.js', array('jquery'), '1.0', true);
	
	wp_enqueue_style( 'aqura_master_css', get_stylesheet_directory_uri() . '/assets/css/master.css');

	wp_enqueue_style( 'aqura_style_css', get_stylesheet_uri() );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'aqura_main_scripts' );

/**
 * Setup Visual Composer plugin for the theme
 */
function aqura_setup_visual_composer() {

	// Disable VC frontend editor
	if(function_exists('vc_disable_frontend')) {
		vc_disable_frontend();
	}

	// Set the vc_path to the new folder
	if ( function_exists('vc_set_shortcodes_templates_dir') ) {
		$dir = get_template_directory() . '/lib/functions/vc_templates/';
		vc_set_shortcodes_templates_dir($dir);
	}
	if(function_exists('vc_set_as_theme')) vc_set_as_theme(true);

	require_once(get_template_directory() . '/lib/functions/visual-composer.php');

}

add_action( 'wp_enqueue_scripts', 'aqura_main_scripts' );

add_action( 'after_setup_theme', 'aqura_setup_visual_composer' );

/*
Register Fonts
*/
function studio_fonts_url() {
    $font_url = '';
    
    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Google font: on', 'aqura' ) ) {
        $font_url = add_query_arg(
        	'family',
        	urlencode( 'Montserrat:400,700|Open Sans:400,300,600,700,800&subset=latin,latin-ext|Lekton|PT Sans:400,700|Libre Baskerville:400,700|Abel|Karla:400,700|Raleway:400,300,500,400italic,300italic,500italic,600,600italic,700,700italic|Raleway Dots|Advent Pro:400,200,700' ),
        	"//fonts.googleapis.com/css"
        );
    }
    return $font_url;
}
/*
Enqueue scripts and styles.
*/
function studio_scripts() {
    wp_enqueue_style( 'studio-fonts', studio_fonts_url(), array(), '1.0.0' );
}
add_action( 'wp_enqueue_scripts', 'studio_scripts' );

/************************************************************/
/* Theme Includes Helpers */
/************************************************************/
if (class_exists('ReduxFramework')) {
	require_once( get_template_directory() . '/admin/redux-framework/options-init.php' );
}

if ( class_exists('RW_Meta_Box') ) {

	/**
	 * Define meta-box constants & require meta-box plugins.
	 *
	 * Meta-box plugin and its extentions are used for the custom content boxes from the posts, pages and other places
	 * in the admin dashboard.
	 */

	require_once( get_template_directory() . '/admin/meta-box-show-hide/meta-box-show-hide.php' );
	require_once( get_template_directory() . '/admin/meta-box-tabs/meta-box-tabs.php' );
	require_once( get_template_directory() . '/lib/functions/aqura-metaboxes.php' );

}

require_once( get_template_directory() . '/lib/functions/core-functions.php' );
require_once( get_template_directory() . '/lib/functions/filters_and_actions.php' );
require_once( get_template_directory() . '/lib/functions/helpers.php' );
require_once( get_template_directory() . '/lib/functions/widgets/widgets.php' );

add_action('after_setup_theme', 'aqura_remove_post_formats', 11);
function aqura_remove_post_formats() {
    remove_theme_support('post-formats');
}

function aquraRemoveReduxNotice() {
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
    }
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );    
    }
}
add_action('init', 'aquraRemoveReduxNotice');

/**
 * Call this files only if we are in the admin area.
 *
 * This is soooo good for optimization of the theme's speed.
 */
if (is_admin()) {
	/**
	 * TGM Activation Plugin
	 *
	 * This plugin helps to call all the required plugins for the theme.
	 */

	require_once( get_template_directory() . '/admin/tgm/tgm-init.php' );

}
