<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Aqura
 */

if ( ! defined( 'ABSPATH' ) ) { exit; }

global $aqura_data;

// $aqura_menu_style = $aqura_data['header-select'];
$aqura_menu_style = 'isNull';
$aqura_logo = $aqura_data['logo']['url'];
$aqura_logo_dark = $aqura_data['logo_dark']['url'];
if (class_exists('ReduxFramework')) {
	$aqura_main_playlist_id = $aqura_data['main-playlist-album-id'];
}

if ( $aqura_logo == '' ) {
	$aqura_logo = AQURA_THEMEROOT . '/assets/img/logo/whiteLogo.png';
}

if ( $aqura_logo_dark == '' ) {
	$aqura_logo_dark = AQURA_THEMEROOT . '/assets/img/logo/logo.png';
}

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="HandheldFriendly" content="true" />
	<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />

	<link rel="profile" href="http://gmpg.org/xfn/11">
	<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">

	<?php if( isset( $aqura_data['favico'] ) && $aqura_data['favico']['url'] != '' ) : ?>
		<link rel="shortcut icon" href="<?php echo esc_url($aqura_data['favico']['url']); ?>" />
	<?php endif; ?>

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php

	$aqura_players_localize = array( 'soundcloud_client_id' => $aqura_data['soundcloud_client_id'] );
	wp_localize_script( 'jPlayer', 'aqura_players_localize', $aqura_players_localize );

?>

<div class="page-loader">
	<div class="vertical-align align-center">
		<img src="<?php echo esc_url(AQURA_IMAGES) ?>/loader.gif" alt="" class="loader-img">
	</div>
</div>

<div id="page" class="site">

	<?php if ( is_front_page() ): ?>
		
		<div class="main-player-opened"></div>

	<?php endif ?>

	<?php if ( $aqura_menu_style == '2' ): ?>
		
	<!-- =============== START ANA-HEADER ================ -->
	<div class="mobile-header">
		<div class="mobile-header-trigger menu-trigger">
			<i class="fa fa-bars"></i>
		</div>
	</div><!-- end mobile-header -->
	<div class="main-header-container">
		<header class="main-header breadHeader clearfix">
			<div class="container">
				<div class="open-albums-button">
					<div data-icon="b" class="icon"></div>
				</div>
				<nav class="main-menu">
					<?php
						if ( has_nav_menu( 'primary' ) ) {

							wp_nav_menu(
								array(
									'theme_location' => 'inline-primary-1',
									'container' 	 => false,
									'items_wrap' 	 => '<ul id="%1$s" class="%2$s">%3$s</ul>'
								));

						}
					?>
				</nav>
				<!-- Header logo container -->
				<div class="logo-container">
					<!-- The big logo -->
					<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="logo-big">
						<img src="<?php echo esc_url($aqura_logo); ?>" alt="<?php echo get_bloginfo('name'); ?> Logo">
					</a>
					<!-- The normal logo -->
					<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="logo">
						<img src="<?php echo esc_url($aqura_logo); ?>" alt="<?php echo get_bloginfo('name'); ?> Logo">
					</a>
				</div>
				<!-- Here is additional buttons for header -->
				<nav class="main-menu additional-buttons">
					<?php
						if ( has_nav_menu( 'primary' ) ) {

							wp_nav_menu(
								array(
									'theme_location' => 'inline-primary-2',
									'container' 	 => false,
									'items_wrap' 	 => '<ul id="%1$s" class="%2$s">%3$s</ul>'
								));

						}
					?>
					<ul class="social-list">
						<?php if(isset($aqura_data)){
							foreach($aqura_data['social'] as $aqura_icon) {
								echo do_shortcode($aqura_icon);
							}
						} ?>
					</ul>
				</nav>
			</div>
		</header>
	</div><!-- end main-header-container -->
	<!-- =============== END ANA-HEADER ================ -->

	<?php else : ?>

	<!-- =============== START TOP HEADER ================ -->
	<div class="topHeader" >
		<div class="header">
			<div class="rightTopHeader">
				<div class="cartContainer">
					<?php if( class_exists( 'WooCommerce' ) ) : ?>
						<?php global $woocommerce; ?>
						<div class="myCart">
							<ul>
								<li class="cartTitle">
									<a href="<?php echo esc_url($woocommerce->cart->get_cart_url()); ?>">
										<img src="<?php echo esc_url(AQURA_IMAGES) ?>/shop/cart.png" alt="">
										<img src="<?php echo esc_url(AQURA_IMAGES) ?>/shop/sh.png" alt="">
										<span><?php echo sprintf( _n( '%d', '%d', $woocommerce->cart->cart_contents_count, 'aqura' ), $woocommerce->cart->cart_contents_count); ?></span>
									</a>
								</li>
							</ul>
						</div>
						<div class="cartParent">
							<div class="cartItems">
								<ul>
									<?php do_action( 'woocommerce_before_cart_contents' ); ?>

									<?php
									foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
										$_product	 = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
										$product_id   = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

										if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
											?>
											<li class="<?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">

												<div class="priceCart">

												<?php
													$thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

													if ( ! $_product->is_visible() )
														echo esc_html($thumbnail);
													else
														printf( '%s', $thumbnail );
												?>

												<?php
													if ( ! $_product->is_visible() )
														echo apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key ) . '&nbsp;';
													else
														echo apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s </a>', $_product->get_permalink( $cart_item ), $_product->get_title() ), $cart_item, $cart_item_key );

													// Meta data
													echo WC()->cart->get_item_data( $cart_item );

									   				// Backorder notification
									   				if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) )
									   					echo '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'aqura' ) . '</p>';
												?>

												<p>
													<?php esc_html_e( 'Price:' , 'aqura' ) ?>&nbsp;
													<?php
														echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key );
													?>
												</p>

												<p class="quantity">
													<?php esc_html_e( 'Quantity: ' , 'aqura' ); ?>
													<span>
														<?php
															echo esc_html($cart_item['quantity']);
														?>
													</span>
												</p>
												
												<?php
													echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf( '<a href="%s" class="remove" title="%s">&times;</a>', esc_url( WC()->cart->get_remove_url( $cart_item_key ) ), esc_html__( 'Remove this item', 'aqura' ) ), $cart_item_key );
												?>

												</div>
											</li>
											<?php
										}
									}

									do_action( 'woocommerce_cart_contents' );
									?>
									
									<?php do_action( 'woocommerce_after_cart_contents' ); ?>
									<li>
										<div class="total">
											<a>
												<?php esc_html_e( 'Sub Total' , 'aqura' ); ?>
												<?php echo WC()->cart->get_cart_total(); ?>
											</a>
										</div>
									</li>
								</ul>
								<?php

									$aqura_cart_url = $woocommerce->cart->get_cart_url();
									$aqura_checkout_url = $woocommerce->cart->get_checkout_url();

								?>
								<a href="<?php echo esc_url($aqura_cart_url); ?>" class="single_add_to_cart_button button alt buttonView">
									<?php esc_html_e('View Cart','aqura') ?>
								</a>
								<a href="<?php echo esc_url($aqura_checkout_url); ?>" class="single_add_to_cart_button button alt buttonCheck">
									<?php esc_html_e('Checkout','aqura') ?>
								</a>
							</div>
						</div>
					<?php endif; ?>
				</div><!--end cartContainer  -->
				<!-- Open Menu Button -->
				<a class="open-menu">
					<!-- Buttons Bars -->
					<span class="span-1"></span>
					<span class="span-2"></span>
					<span class="span-3"></span>
				</a>
			</div><!-- end rightTopHeader -->
		</div><!-- end header -->
		<!-- Menu Fixed Container -->
		<div class="menu-fixed-container">
			<!-- Menu Fixed Centred Container -->
			<nav>
				<!-- Menu Fixed Close Button -->
				<div class="x-filter">
					<span></span>
					<span></span>
				</div>
				<?php
					if ( has_nav_menu( 'primary' ) ) {

						wp_nav_menu(
							array(
								'theme_location' => 'primary',
								'container' 	 => false,
								'items_wrap' 	 => '<ul id="%1$s" class="%2$s">%3$s</ul>'
							));

					} else {

						wp_nav_menu(
							array(
								'container' 	 => false,
								'items_wrap' 	 => '<ul id="%1$s" class="%2$s">%3$s</ul>'
							));

					}
				?>
				<!-- Menu Fixed Close Button -->
				<div class="x-filter">
					<span></span>
					<span></span>
				</div>
			</nav>
		</div><!-- end menu-fixed-container -->
		<!-- =============== STAR LOGO ================ -->
		<div class="logo-container-top">
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>">
				<img src="<?php echo esc_url($aqura_logo); ?>" alt="<?php echo get_bloginfo('name'); ?> Logo">
				<img src="<?php echo esc_url($aqura_logo_dark); ?>" alt="<?php echo get_bloginfo('name'); ?> Logo">
			</a>
		</div><!-- end logo-container-top -->
		<!-- =============== END LOGO ================ -->
	</div><!-- end topHeader -->
	<!-- =============== END TOP HEADER ================ -->

	<?php endif ?>

	<!-- =============== START PLAYER ================ -->
	<div class="main-music-player">
		<a class="hide-player-button">
			<i class="fa fa-chevron-up"></i>
			<i class="fa fa-chevron-down"></i>
		</a>
		<div id="mesh-main-player" class="jp-jplayer"></div>
		<div id="mesh-main-player-content" class="mesh-main-player" role="application" aria-label="media player">
			<div class="container">
				<div class="row">
					<div class="left-player-side">
						<div class="mesh-prev">
							<i class="fa fa-step-backward"></i>
						</div>
						<div class="mesh-play">
							<i class="fa fa-play"></i>
						</div>
						<div class="mesh-pause">
							<i class="fa fa-pause"></i>
						</div>
						<div class="mesh-next">
							<i class="fa fa-step-forward"></i>
						</div>
						<button id="playlist-toggle" class="jplayerButton">
							<span class="span-1"></span>
							<span class="span-2"></span>
							<span class="span-3"></span>
						</button>
					</div>
					<div class="center-side">
						<div class="mesh-current-time">
						</div>
						<div class="mesh-seek-bar">
							<div class="mesh-play-bar">
							</div>
						</div>
						<div class="mesh-duration">
						</div>
					</div>
					<div class="right-player-side">
						<div class="mesh-thumbnail">
							<img src="#" alt="">
						</div>
						<div class="mesh-title">
						</div>
						<div class="mesh-artist">
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
	<!-- =============== END PLAYER ================ -->

	<!-- =============== START PLAYLIST ================ -->
	<div class="playlist-wrapper" id="playlist-wrapper">
		<?php

			$aqura_args = array();

			if ( $aqura_main_playlist_id != '' ) {

					$aqura_tracks = rwmb_meta('album-tracks',$aqura_args,$aqura_main_playlist_id);

					if ( $aqura_tracks ) {

		?>
		<div class="jp-playlist container">
			<div class="about-list clearfix">
				<span class="about-name">
					<?php esc_html_e( 'NAME' , 'aqura' ) ?>
				</span>
				<span class="about-length">
					<?php esc_html_e( 'LENGTH' , 'aqura' ) ?>
				</span>
				<span class="about-available">
					<?php esc_html_e( 'AVAILABLE ON' , 'aqura' ) ?>
				</span>
			</div>
			<?php

					$aqura_album_itunes = rwmb_meta( 'aqura_album_itunes',$aqura_args,$aqura_main_playlist_id );
					$aqura_album_soundcloud = rwmb_meta( 'aqura_album_soundcloud',$aqura_args,$aqura_main_playlist_id );
					$aqura_album_beatport = rwmb_meta( 'aqura_beatport',$aqura_args,$aqura_main_playlist_id );

					foreach ($aqura_tracks as $key => $aqura_track):

						if ( isset($aqura_track['track-external-url']) ):
								
							$aqura_trak_final = $aqura_track['track-external-url'];

							if (strpos($aqura_track['track-external-url'], 'soundcloud') !== false) :

								$sc_condition = 'data-sc="true"';

							endif;

						else:

							$aqura_trak_final = wp_get_attachment_url($aqura_track['track-url'][0]);

							$sc_condition = '';

						endif;

						if (isset($aqura_track['track-name'])): ?>

							<div class="trak-item" data-audio="<?php echo esc_url($aqura_trak_final); ?>" data-artist="<?php echo esc_attr($aqura_track['track-author']); ?>" data-thumbnail="<?php echo wp_get_attachment_url($aqura_track['track-thumbnail'][0]); ?>" <?php echo $sc_condition; ?>>
									<audio src="<?php echo esc_url($aqura_trak_final); ?>" preload="none" title="<?php echo esc_attr($aqura_track['track-name']); ?>"></audio>
									<?php if ( $aqura_album_itunes != '' || $aqura_album_soundcloud != '' || $aqura_album_beatport != '' ): ?>
									<div class="additional-button">
										<div class="center-y-table">
											<?php if ( $aqura_album_itunes != '' ): ?>
												<a href="<?php echo esc_url($aqura_album_itunes); ?>">
													<i class="fa fa-apple"></i>
												</a>
											<?php endif ?>
											<?php if ( $aqura_album_soundcloud != '' ): ?>
												<a href="<?php echo esc_url($aqura_album_soundcloud); ?>">
													<i class="fa fa-soundcloud"></i>
												</a>
											<?php endif ?>
											<?php if ( $aqura_album_beatport != '' ): ?>
												<a href="<?php echo esc_url($aqura_album_beatport); ?>">
													<i class="fa fa-headphones"></i>
												</a>
											<?php endif ?>
										</div>
									</div>
									<?php endif ?>
									<div class="play-pause-button">
										<div class="center-y-table">
											<i class="fa fa-play"></i>
										</div>
									</div>
									<div class="name-artist">
										<div class="center-y-table">
											<h2>
												<?php echo esc_html($aqura_track['track-name']); ?>
											</h2>
										</div>
									</div>
									<time class="trak-duration" datetime="<?php echo get_the_date('Y-m-d', $aqura_main_playlist_id); ?>">
										<?php if (isset($aqura_track['track-external-url'])): ?>
								
											<?php echo $aqura_track['track-duration']; ?>

										<?php else: ?>

											<?php

												$aqura_tracktime = isset($aqura_track['track-url'][0]) ? wp_get_attachment_metadata($aqura_track['track-url'][0]) : '';

												if ($aqura_tracktime):
													echo esc_html($aqura_tracktime['length_formatted']);
												else:
													echo esc_html($aqura_track['track-duration']);
												endif;

											?>

										<?php endif ?>
									</time>
								</div>

						<?php endif;
					endforeach;

				}

			?>
		</div>
		<?php } ?>
	</div>
	<!-- =============== END PLAYLIST ================ -->