<?php
/**
 * @author Aqura
 */

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }

/**
 * Count words based on wp_trim_words() function.
 *
 * @param $aqura_text string
 * @param $num_words int
 *
 * @return int
 */
function aqura_count_words( $aqura_text, $num_words = 55 ) {
    $aqura_text = wp_strip_all_tags( $aqura_text );
    /* translators: If your word count is based on single characters (East Asian characters),
       enter 'characters'. Otherwise, enter 'words'. Do not translate into your own language. */
    if ( 'characters' == _x( 'words', 'word count: words or characters?', 'aqura' ) && preg_match( '/^utf\-?8$/i', get_option( 'blog_charset' ) ) ) {
        $aqura_text = trim( preg_replace( "/[\n\r\t ]+/", ' ', $aqura_text ), ' ' );
        preg_match_all( '/./u', $aqura_text, $aqura_words_array );
        $aqura_words_array = array_slice( $aqura_words_array[0], 0, null );
    } else {
        $aqura_words_array = preg_split( "/[\n\r\t ]+/", $aqura_text, -1, PREG_SPLIT_NO_EMPTY );
    }

    return count( $aqura_words_array );
}


/* Convert hexdec color string to rgb(a) string */
/**
 * @param $color
 * @param bool $opacity
 * @return string
 */
function aqura_hex2rgba($color, $opacity = false) {

    $default = 'rgb(0,0,0)';

    //Return default if no color provided
    if(empty($color))
        return $default;

    //Sanitize $color if "#" is provided
    if ($color[0] == '#' ) {
        $color = substr( $color, 1 );
    }

    //Check if color has 6 or 3 characters and get values
    if (strlen($color) == 6) {
        $hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
    } elseif ( strlen( $color ) == 3 ) {
        $hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
    } else {
        return $default;
    }

    //Convert hexadec to rgb
    $rgb =  array_map('hexdec', $hex);

    //Check if opacity is set(rgba or rgb)
    if($opacity){
        if(abs($opacity) > 1)
            $opacity = 1.0;
        $aqura_output = 'rgba('.implode(",",$rgb).','.$opacity.')';
    } else {
        $aqura_output = 'rgb('.implode(",",$rgb).')';
    }

    //Return rgb(a) color string
    return $aqura_output;
}

class aqura_Core {

    protected static $instance = null;

    /**
     * The Mailchimp API key.
     *
     * @since   1.0.0
     * @var     string
     */
    private $mailchimp_apikey;

    /**
     * The Mailchimp list ID.
     *
     * @since   1.0.0
     * @var     string
     */
    private $mailchimp_list_id;

    private function __construct() {

        add_action( 'aqura_before_subscribe', array( &$this, 'wait_for_subscribe' ) );

        $this->include_other_classes();

        global $aqura_data;

    }

    /**
     * Include other classes files, required for the theme
     *
     * @since   1.0.0
     */
    private function include_other_classes() {

        

    }

    public function wait_for_subscribe($ID) {

        if(isset($_REQUEST['_sth-subscribe']) && wp_verify_nonce( $_REQUEST['_sth-subscribe'], 'subscribe-user_'.$ID )) {

            $email = sanitize_email($_REQUEST['aqura_email']);
            // $name = sanitize_text_field($_REQUEST['aqura_name']);

            global $aqura_data;

            if($email) {

                if($this->subscribe_to_mailchimp($email) && $aqura_data['subscribe_thankyou_page' ] != '') {

                    header( 'Location: ' . get_permalink( intval($aqura_data['subscribe_thankyou_page' ]) ));

                }

            }

        }

    }

    /**
     * Subscribe the given email address to our Mailchimp List.
     *
     * @since 1.0.0
     * @param $email_address
     * @return array
     */
    private function subscribe_to_mailchimp($email_address, $name = '') {

        $MailChimp = new \Drewm\MailChimp($this->mailchimp_apikey);

        global $aqura_data;

        $result = $MailChimp->call('lists/subscribe', array(
            'id'                => $this->mailchimp_list_id,
            'email'             => array('email' => $email_address),
            'merge_vars'        => $name != '' ? array('FNAME'=> $name) : array(),
            'double_optin'      => $aqura_data['mailchimp-email-verification'],
            'update_existing'   => true,
            'replace_interests' => false,
            'send_welcome'      => $aqura_data['mailchimp-email-send-welcome'],
        ));

        return $result;

    }

    /**
     * @return aqura_Core|null
     */
    public static function get_instance() {

        // If the single instance hasn't been set, set it now.
        if ( null == self::$instance ) {
            self::$instance = new self;
        }

        return self::$instance;
    }

}

aqura_Core::get_instance();