<?php
/**
 * The template for displaying all single posts.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#single-post
 *
 * @package Aqura
 */

if ( ! defined( 'ABSPATH' ) ) { exit; }

$aqura_title = rwmb_meta( 'aqura_single_article_title' );
$aqura_small_description = rwmb_meta( 'aqura_small_description' );
$aqura_view_more_text = rwmb_meta( 'aqura_view_more_text' );
$aqura_article_type = rwmb_meta( 'aqura_article_type' );
$aqura_soundcloud_id = rwmb_meta( 'aqura_soundcloud_id' );
$aqura_video_id = rwmb_meta( 'aqura_video_id' );
$aqura_gallery_images_post = rwmb_meta( 'aqura_gallery_images_post', 'type=image' );

$aqura_feat_image = wp_get_attachment_url( get_post_thumbnail_id($post->ID) );

global $user_identity;

$aqura_post_sidebar_hide = rwmb_meta( 'post_sidebar_hide' );
$aqura_commenter = wp_get_current_commenter();
$aqura_req = get_option( 'require_name_email' );
$aqura_aria_req = ( $aqura_req ? " aria-required='true'" : '' );

$aqura_fields =  array(
	'author' => '<input id="author" name="author" type="text" value="' . esc_attr($aqura_commenter['comment_author']) . '" ' . $aqura_aria_req . ' placeholder="' . esc_html__('Name... ', 'aqura') . '" />',

	'email' => '<input id="email" name="email" type="text" value="' . esc_attr($aqura_commenter['comment_author_email']) . '" ' . $aqura_aria_req . ' placeholder="' . esc_html__('Email... ', 'aqura') . '"/>',

	'website' => '<input id="website" name="website" type="text" value="' . esc_attr($aqura_commenter['comment_author_email']) . '" ' . $aqura_aria_req . ' placeholder="' . esc_html__('Website... ', 'aqura') . '"/>',

	'comment_field' => '<textarea id="comment" name="comment" cols="45" rows="8" aria-required="true" ' .
							'placeholder="' . esc_html__('Your comment ', 'aqura') . '"/>' .
						'</textarea>',
);

$aqura_args = array(
	'id_form'					 => 'commentform',
	'id_submit'				 => 'submit',
	'class_submit'			=> 'submit',
	'name_submit'			 => 'submit',
	'title_reply'			 => esc_html__( 'Leave a comment' , 'aqura' ),
	'title_reply_to'		=> esc_html__( 'Leave a comment to %s' , 'aqura' ),
	'cancel_reply_link' => esc_html__( 'Cancel Reply', 'aqura' ),
	'label_submit'			=> esc_html__( 'Post Comment' , 'aqura' ),
	'format'						=> 'xhtml',
	'comment_field' =>	'',
	'comment_notes_before' => '',
	'fields' => apply_filters( 'comment_form_default_fields', $aqura_fields ),
	'logged_in_as' => '<p class="logged-in-as">' . sprintf( esc_html__('Logged in as ', 'aqura') . '<a href="%1$s">%2$s</a>. <a href="%3$s" title="' . esc_html__('Log out of this account ', 'aqura') . '">' . esc_html__('Log out?', 'aqura') . '</a>', admin_url( 'profile.php' ), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink() ) ) ) . '</p>' . $aqura_fields['comment_field']
);

get_header(); ?>

	<!-- =============== START BREADCRUMB ================ -->
	<section class="no-mb">
		<div class="row">
			<div class="col-sm-12">
				<div class="breadcrumb-fullscreen-parent phone-menu-bg">
					<div class="breadcrumb breadcrumb-fullscreen alignleft small-description overlay almost-black-overlay" style="<?php if ($aqura_feat_image != '') { ?>background-image: url(<?php echo esc_url($aqura_feat_image); ?>);<?php } else { ?> background-color: #333; <?php } ?>" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
						<div class="breadTxt">
                            <h1>
                            	<?php if ( $aqura_title != '' ): ?>
                            		<?php echo esc_html($aqura_title); ?>
                            	<?php else: ?>
                            		<?php echo esc_html(get_the_title()); ?>
                            	<?php endif ?>
                            </h1>
                            <p>
								<?php echo balanceTags($aqura_small_description); ?>
							</p>
                            <a href="#content" data-easing="easeInOutQuint" data-scroll="" data-speed="900" data-url="false">
                            	<?php

                            		if ( $aqura_view_more_text != '' ) {
                            			echo esc_html($aqura_view_more_text);
                            		} else {
                            			esc_html_e( 'View More' , 'aqura');
                            		}

                            	?> <i class="fa fa-angle-down"></i>
                            </a>
                        </div>
					</div>
				</div>
			</div>
		</div>
	</section>
	<div id="content"></div>
	<!-- =============== END BREADCRUMB ================ -->

	<!-- =============== START BLOG SINGLE ================ -->
	<section class="blogSingle padding">
		<div class="container">
			<div class="row">
				<div class="blog-left">
					<div class="col-sm-8">
						<?php while ( have_posts() ) : the_post(); ?>
						<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
							<?php if ( $aqura_article_type === 'soundcloud' ): ?>

								<?php if ( $aqura_soundcloud_id != '' ): ?>
									
									<iframe width="100" height="53"  src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_attr($aqura_soundcloud_id); ?>&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false&amp;visual=true"></iframe>

								<?php endif ?>
								
							<?php elseif ( $aqura_article_type === 'youtube' ) : ?>

								<?php if ( $aqura_video_id != '' ): ?>

									<iframe width="560" height="315" src="https://www.youtube.com/embed/<?php echo esc_attr($aqura_video_id); ?>" allowfullscreen></iframe>

								<?php endif ?>

							<?php elseif ( $aqura_article_type === 'vimeo' ) : ?>

								<?php if ( $aqura_video_id != '' ): ?>

									<iframe src="https://player.vimeo.com/video/<?php echo esc_attr($aqura_video_id); ?>?title=0&byline=0&portrait=0" allowfullscreen></iframe>

								<?php endif ?>

							<?php elseif ( $aqura_article_type === 'gallery' ) : ?>

								<?php if ( $aqura_gallery_images_post != '' ): ?>


									<div class="owl-carousel">

									<?php

										foreach ( $aqura_gallery_images_post as $image ) {

											$aqura_gallery_images_post_display = $image['full_url'];

											echo '<div class="item"><img src="' . $aqura_gallery_images_post_display . '" alt=""></div>';
										}

									?>

									</div>

								<?php endif ?>

							<?php endif; ?>
							<div class="admin-list clearfix">
								<ul>
									<li>
										<a href="<?php echo get_month_link(get_the_time('Y'), get_the_time('m')); ?>">
											<?php echo get_the_date('d M Y'); ?>
										</a>
										&nbsp;/&nbsp;
									</li>
									<li>
										<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>">
											<?php esc_html_e('By ' , 'aqura') ?>
											<?php the_author(); ?>
										</a>
										&nbsp;/&nbsp;
									</li>
									<li>
										<?php

											$aqura_categories = get_the_category();
											$aqura_separator = ' ';
											$aqura_output = '';

											if ( ! empty( $aqura_categories ) ) :
												foreach( $aqura_categories as $category ) {
													$aqura_output .= '<a href="' . $category->permalink . '">';
														$aqura_output .= esc_html( $category->name ) . $aqura_separator;
													$aqura_output .= '</a>';
												}
												echo trim( $aqura_output, $aqura_separator );
											endif;
										?>
										&nbsp;/&nbsp;
									</li>
									<li>
										<a href="#comments">
											<?php

												comments_number(__('No Comments', 'aqura'), '1 ' . esc_html__(' Comment', 'aqura'), '%  ' . esc_html__('Comments', 'aqura'));

											?>
										</a>
									</li>
								</ul>
							</div>
							<div class="title">
								<?php the_title( '<h2 class="entry-title">', '</h2>' ); ?>
							</div>
							<div class="paragraph">
								<?php

									the_content( sprintf(
										/* translators: %s: Name of current post. */
										wp_kses( esc_html__( 'Continue reading %s <span class="meta-nav">&rarr;</span>', 'aqura' ), array( 'span' => array( 'class' => array() ) ) ),
										the_title( '<span class="screen-reader-text">"', '"</span>', false )
									) );

									wp_link_pages( array(
										'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'aqura' ),
										'after'  => '</div>',
									) );

								?>
							</div>
							<div class="tagBlogSingle">
								<div class="content">
									<p>Tag Cloud:</p>
									<?php

										$aqura_posttags = get_the_tags();
										if ($aqura_posttags) {
											foreach($aqura_posttags as $tag) {
												echo '<a href="' . get_tag_link($tag->term_id) . '">';
													echo esc_html($tag->name . ' '); 
												if ( $tag === end($aqura_posttags) ) {
													echo '</a>';
												} else {
													echo '</a>&nbsp;/&nbsp;';
												}
											}
										}

									?>
								</div>
							</div>

							<div class="author-info">
								<div class="left-author-info">
									<figure>
										<?php echo get_avatar( $comment, 44 ); ?>
									</figure>
								</div>
								<div class="right-author-info">
									<h1>
										<?php esc_html_e('By ' , 'aqura') ?>
										<?php the_author(); ?>
									</h1>
									<p>
										<?php echo get_the_author_meta( 'description' ); ?>
									</p> 
								</div>
							</div>

							<div id="comments">

							<?php

								do_all_pings();

								if ( get_comments_number() ) :
									comments_template();
								endif;

							?>

							</div>

							<div class="singleBlogForm">
								<?php comment_form( $aqura_args ); ?>
							</div>

						<?php

							endwhile; // End of the loop.
						?>
						</article>
					</div><!-- end col-sm-8 -->
				</div><!-- end blog-left -->
				<div class="blog-right">
					<div class="col-sm-3 col-sm-offset-1">
						<div class="blogSidebar">
							<?php get_sidebar(); ?>
						</div><!-- end blogSidebar -->
					</div><!-- end col-sm03 -->
				</div><!-- end blog-right -->
			</div><!-- end row -->
		</div><!-- end container -->
	</section>
	<!-- =============== END BLOG SINGLE ================ -->

	<!-- =============== START PAGINATION ================ -->
	<section class="paginationFooter ">
		<div class="container">
			<div class="row">
				<div class="col-sm-12">
					<?php aqura_post_single_nav(get_the_ID(), 'post'); ?>
				</div>
			</div>
		</div>
	</section>
	<!-- =============== END PAGINATION ================ -->

<?php

get_footer();