<?php
/**
 * Template part for displaying results in search pages.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Aqura
 */

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }

$aqura_article_type = rwmb_meta( 'aqura_article_type' );
$aqura_soundcloud_id = rwmb_meta( 'aqura_soundcloud_id' );
$aqura_video_id = rwmb_meta( 'aqura_video_id' );
$aqura_gallery_images = rwmb_meta( 'aqura_gallery_images_post', 'type=image' );

?>

<article <?php echo post_class('blogBox'); ?>>	
	<?php if ( $aqura_article_type === 'soundcloud' ): ?>

		<?php if ( $aqura_soundcloud_id != '' ): ?>
			
			<iframe width="100" height="53"  src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_attr($aqura_soundcloud_id); ?>&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false&amp;visual=true"></iframe>

		<?php endif ?>
		
	<?php elseif ( $aqura_article_type === 'youtube' ) : ?>

		<?php if ( $aqura_video_id != '' ): ?>

			<iframe width="560" height="315" src="https://www.youtube.com/embed/<?php echo esc_attr($aqura_video_id); ?>" allowfullscreen></iframe>

		<?php endif ?>

	<?php elseif ( $aqura_article_type === 'vimeo' ) : ?>

		<?php if ( $aqura_video_id != '' ): ?>

			<iframe src="https://player.vimeo.com/video/<?php echo esc_attr($aqura_video_id); ?>?title=0&byline=0&portrait=0" allowfullscreen></iframe>

		<?php endif ?>

	<?php elseif ( $aqura_article_type === 'gallery' ) : ?>

		<?php if ( $aqura_gallery_images != '' ): ?>


			<div class="owl-carousel">

			<?php

				foreach ( $aqura_gallery_images as $image ) {

					$aqura_gallery_images_display = $image['full_url'];

					echo '<div class="item"><img src="' . $aqura_gallery_images_display . '" alt=""></div>';
				}

			?>

			</div>

		<?php endif ?>

	<?php endif ?>
	<div class="blogBoxContent">
		<div class="blogHeader">
			<h1>
				<a href="<?php echo esc_url(get_permalink()); ?>">
					<?php echo esc_html($post->post_title); ?>
				</a>
			</h1>
		</div>
		<div class="admin-list clearfix">
			<ul>
				<li>
					<a href="<?php echo get_month_link(get_the_time('Y'), get_the_time('m')); ?>">
						<?php echo get_the_date('d M Y'); ?>
					</a>
					&nbsp;/&nbsp;
				</li>
				<li>
					<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>">
						<?php esc_html_e('By ' , 'aqura') ?>
						<?php the_author(); ?>
					</a>
					&nbsp;/&nbsp;
				</li>
				<li>
					<?php

						$aqura_categories = get_the_category();
						$aqura_separator = ' ';
						$aqura_output = '';

						if ( ! empty( $aqura_categories ) ) :
							foreach( $aqura_categories as $category ) {
								$aqura_output .= '<a href="' . $category->permalink . '">';
									$aqura_output .= esc_html( $category->name ) . $aqura_separator;
								$aqura_output .= '</a>';
							}
							echo trim( $aqura_output, $aqura_separator );
						endif;
					?>
					&nbsp;/&nbsp;
				</li>
				<li>
					<a>
						<?php

							comments_number(__('No Comments', 'aqura'), '1 ' . esc_html__(' Comment', 'aqura'), '%  ' . esc_html__('Comments', 'aqura'));

						?>
					</a>
				</li>
			</ul>
		</div>
		<div class="blogParagraph">
			<?php the_excerpt(); ?>
		</div><!--end blogParagraph  -->
		<div class="rmButton">
			<a href="<?php echo esc_url(get_permalink()); ?>">
				<?php esc_html_e( 'Read More' , 'aqura' ); ?>
			</a>
		</div>		
	</div><!-- end blogBoxContent -->
</article><!-- end blogBox -->
